#!/usr/bin/perl -w

use Test::More 'no_plan';

package Catch;

sub TIEHANDLE {
    my($class, $var) = @_;
    return bless { var => $var }, $class;
}

sub PRINT  {
    my($self) = shift;
    ${'main::'.$self->{var}} .= join '', @_;
}

sub READ {}
sub READLINE {}
sub GETC {}

my $Original_File = 'root/etc/e-smith/events/post-upgrade/S70sshd-conf-startup';

package main;

# pre-5.8.0's warns aren't caught by a tied STDERR.
$SIG{__WARN__} = sub { $main::_STDERR_ .= join '', @_; };
tie *STDOUT, 'Catch', '_STDOUT_' or die $!;
tie *STDERR, 'Catch', '_STDERR_' or die $!;

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 48 root/etc/e-smith/events/post-upgrade/S70sshd-conf-startup

use esmith::ConfigDB;

$Destruct_Ok = 
  eval { esmith::ConfigDB->open->get('testing')->prop('destruction') } || 0;

my $Scratch = 'scratch.conf';
unlink $Scratch;
$ENV{ESMITH_CONFIG_DB} = $Scratch;
esmith::ConfigDB->create($Scratch);  # so the action has something
END { unlink $Scratch }

system $^X, $Original_File;
is( $@, '', 'ran myself ok' );

my $db = esmith::ConfigDB->open;

ok( my $sshd = $db->get('sshd'), 'sshd config exists' );

is( $sshd->prop('status'), 'disabled', 'sshd is disabled' );
is( $sshd->prop('PasswordAuthentication'), 'yes', 
                              "    PasswordAuth is set to the default" );
is( $sshd->prop('PermitRootLogin'),        'no',
                              "    PermitRootLogin is set to the default" );
is( $sshd->prop('access'),                 'private',
                              "    access is set to the default" );



SKIP: {
    skip "sshd reconfiguration would be destructive", 6
      unless $Destruct_Ok;

    # Use the real configuration.
    local $ENV{ESMITH_CONFIG_DB};

    skip "You have to be able to read the config DB to test this", 6
       unless $db = esmith::ConfigDB->open;

    # Call ourself.
    system $^X, $Original_File;
    is( $@, '', 'ran myself ok' );

    ok( my $sshd = $db->get('sshd'), 'sshd config exists' );

    foreach my $prop (qw(status access
                         PasswordAuthentication PermitRootLogin))
    {
        ok( $sshd->prop($prop),       "    $prop is defined" );
    }
}


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

